==> flowFlowJo_1.2.0.tar.gz: flowFlowJo/R/collectSummaryFlowInfo.R <==
## HANDLE SINGLE FLOW FRAMES AT A TIME.
setMethod("collectSummaryFlowInfo",
          signature(fj = "flowJoList"),
          definition = function(fj, 
                                fileNamePatterns=NULL, 
                                gateNamePattern=NULL, 
                                upperCaseGates=FALSE,
                                keywords=NULL, 
                                stripGutters=FALSE, 
                                method="median") {

  resultsList = new("fcsSummaryList");
  usedCount   = 1;
  totGateVec  = vector();
  totChanVec  = vector();
  
  for (wsNum in 1:length(fj@FlowJoWorkspace)) {
    aFlowJoObj  = fj@flowJoData[[wsNum]];   # a single FlowJo workspace
    fileList    = as.character(unique(aFlowJoObj@FCSFilename));
    for (fileNum in 1:length(fileList)) {
      aFile       = fileList[fileNum];   # a single FCS file

      # Skip files if they don't match a certain pattern in their name
      if (! is.null(fileNamePatterns)) {
        if (length(grep(fileNamePatterns, aFile)) == 0) {
          print(paste("  Skipping:", basename(aFile)));
          next;
        }
      } 
      
      cat(paste("  Working on ", usedCount, basename(aFile), "\n"));
      fileIndex   = which(aFlowJoObj@FCSFilename == aFile);
      compLookUp  = aFlowJoObj@useCompMatrix[ fileIndex[1] ];
      aCompMatrix = aFlowJoObj@uniCompList[[compLookUp]];
      aFlowFrame  = read.FCS(aFile);
      aFlowFrame  = flowJoCompensate(flowData=aFlowFrame, compMatrix=aCompMatrix);
      
      # To do:  strip gutters      
 #     if (stripGutters) { aFlowFrame = stripGutters(aFlowFrame); }
      
      # To do:  indicate warnings or unusual flow events    
      comments    = "";
      
      # Collect info from the 'text' field in the header of each FCS file
      textList    = list();
      if (is.vector(keywords)) {
        for (key in keywords) {
          textList[[key]] = as.character(keyword(aFlowFrame, key));
        }
      }
      
      # Assemble a matrix of gates (populations)  X  channels
      channelList = names(aFlowFrame);
      wellId      = getWellId(aFlowFrame);      
      resultsMat  = matrix(nrow=length(fileIndex), ncol=length(channelList)+1, byrow=TRUE);
      j           = 1; 
      for (i in fileIndex) {
        aPop = Subset(aFlowFrame, aFlowJoObj@filter[[i]]);
#        aFilterResult = filter(aFlowFrame, aFlowJoObj@filter[[i]]);
#        aBitMask      = aFilterResult@subSet;
        mfis = summary(aPop)["Median",];
        resultsMat[j,] = c(mfis, nrow(aPop));
        j = j + 1;
      }
      colnames(resultsMat) <- c(channelList, "Count");   
      gateNames            <- aFlowJoObj@filterName[fileIndex];                              
      rownames(resultsMat) <- simplifyGateNames(gateNames, 
                                                upperCaseGates=upperCaseGates);
      totChanVec  <- c(totChanVec, colnames(resultsMat));
      totGateVec  <- c(totGateVec, rownames(resultsMat))

      anFCSSummary = new("fcsSummary", fcsName           = basename(aFile),
                                       FCSFilename       = aFile,
                                       FlowJoWorkspace   = fj@FlowJoWorkspace[wsNum],
                                       wellId            = wellId,
                                       popMat            = resultsMat,
                                       textList          = textList,
                                       QCComments        = comments);
      
      print(fileNum);      
      resultsList@summaries[[usedCount]] = anFCSSummary;
      usedCount = usedCount + 1;
    }
  }  

  # Count up some summary statistics
  resultsList@gateTable    = table(totGateVec);
  resultsList@channelTable = table(totChanVec);
  
  return(resultsList);
});

==> flowFlowJo_1.16.0.tar.gz: flowFlowJo/R/collectSummaryFlowInfo.R <==
## HANDLE SINGLE FLOW FRAMES AT A TIME.
setMethod("collectSummaryFlowInfo",
          signature(fj = "flowJoList"),
          definition = function(fj, 
                                fileNamePatterns=NULL, 
                                gateNamePattern=NULL, 
                                upperCaseGates=FALSE,
                                keywords=NULL, 
                                stripGutters=FALSE, 
                                method="median") {

  resultsList = new("fcsSummaryList");
  usedCount   = 1;
  totGateVec  = vector();
  totChanVec  = vector();
  
  for (wsNum in 1:length(fj@FlowJoWorkspace)) {
    aFlowJoObj  = fj@flowJoData[[wsNum]];   # a single FlowJo workspace
    fileList    = as.character(unique(aFlowJoObj@FCSFilename));
    for (fileNum in 1:length(fileList)) {
      aFile       = fileList[fileNum];   # a single FCS file

      # Skip files if they don't match a certain pattern in their name
      if (! is.null(fileNamePatterns)) {
        if (length(grep(fileNamePatterns, aFile)) == 0) {
          cat("  Skipping:", basename(aFile), "\n");
          next;
        }
      } 
      
      cat("  Working on file ", usedCount, ": ", basename(aFile), "\n");
      fileIndex   = which(aFlowJoObj@FCSFilename == aFile);
      compLookUp  = aFlowJoObj@useCompMatrix[ fileIndex[1] ];
      aCompMatrix = aFlowJoObj@uniCompList[[compLookUp]];
      aFlowFrame  = read.FCS(aFile);
      aFlowFrame  = flowJoCompensate(flowData=aFlowFrame, compMatrix=aCompMatrix);
      
      # To do:  strip gutters      
 #     if (stripGutters) { aFlowFrame = stripGutters(aFlowFrame); }
      
      # To do:  indicate warnings or unusual flow events    
      comments    = "";
      
      # Collect info from the 'text' field in the header of each FCS file
      textList    = list();
      if (is.vector(keywords)) {
        for (key in keywords) {
          textList[[key]] = as.character(keyword(aFlowFrame, key));
        }
      }
      
      # Assemble a matrix of gates (populations)  X  channels
      channelList = names(aFlowFrame);
      wellId      = getWellId(aFlowFrame);      
      resultsMat  = matrix(nrow=length(fileIndex), ncol=length(channelList)+1, byrow=TRUE);
      j           = 1; 
      for (i in fileIndex) {
        aPop = Subset(aFlowFrame, aFlowJoObj@filter[[i]]);
        medianFI = summary(aPop)["Median",];
        meanFI   = summary(aPop)["Mean",]
        if (nrow(aPop) < 2) {
           modeFI = meanFI
        } else {
           modeFI = unlist(apply(exprs(aPop), 2, function(x) {
                              aDens = density(x);
                              value = aDens$x[aDens$y == max(aDens$y, na.rm=TRUE)];
                              return(signif(value, 4)) }))
        }

        resultsMat[j,] = c(meanFI, nrow(aPop));
        j = j + 1;
      }
      colnames(resultsMat) <- c(channelList, "Count");   
      gateNames            <- aFlowJoObj@filterName[fileIndex];                              
      rownames(resultsMat) <- simplifyGateNames(gateNames, 
                                                upperCaseGates=upperCaseGates);
      totChanVec  <- c(totChanVec, colnames(resultsMat));
      totGateVec  <- c(totGateVec, rownames(resultsMat))

      anFCSSummary = new("fcsSummary", fcsName           = basename(aFile),
                                       FCSFilename       = aFile,
                                       FlowJoWorkspace   = fj@FlowJoWorkspace[wsNum],
                                       wellId            = wellId,
                                       popMat            = resultsMat,
                                       textList          = textList,
                                       QCComments        = comments);
            
      resultsList@summaries[[usedCount]] = anFCSSummary;
      usedCount = usedCount + 1;
    }
  }  

  # Count up some summary statistics
  resultsList@gateTable    = table(totGateVec);
  resultsList@channelTable = table(totChanVec);
  
  return(resultsList);
});
